#-*- coding: utf-8 -*-

'''
Primo esempio (example_01.py) : Implementazione di uno sfondo
                                per una finestra

Per farlo utilizza una label e il gestore di geometria "place",
la label viene inserita alla coordinata (0,0) e le vengono assegnate
le proprietà per l'occupazione dell'intera altezza (relheight) e
larghezza (relwidth) del widget genitore, estresse in frazione
percentuale (1.0 = 10%.

Inseriti, in surplus, il dimensionamento minimo della finestra alla
dimensione immagine e la centratura sullo schemo (funzione center_window),
ridondanti ma simpatiche.
'''

import tkinter as tk
from PIL import Image, ImageTk

class MainWin(tk.Tk):
    def __init__(self, img, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.title('Test background image')
        # carico immagine da file, ne memorizzo una copia e
        # la assegno ad una label
        self.img = Image.open(img)
        self.img_copy = self.img.copy()
        self.bg_image = ImageTk.PhotoImage(self.img)
        self.bg_label = tk.Label(self, image=self.bg_image)
        # piazzo la label all'angolo (0,0) ed indico di occupare
        # l'intera altezza/larghezza del parent (la finestra)
        self.bg_label.place(x=0, y=0, relwidth=1.0, relheight=1.0)
        # definisco una variabile per indicare lo stato di inizializzazione
        self.load = True
        # intercetto l'evento '<Configure>' della label
        self.bg_label.bind('<Configure>', self._resize_background)

    def _verify_init(self):
        ''' Adatto la finestra alla dimensione immagine e
            definisce la dimesione risultante quale minima.'''
        # rileva le dimensioni immagine e le assegna alla finestra
        w = self.img.width
        h = self.img.height
        self.configure(width=w, height=h)
        # aggiorna la finestra e stabilisce le dimensioni minime
        self.update()
        self.minsize(self.winfo_reqwidth(), self.winfo_reqheight())
        center_window(self)
        self.load = False
        
    def _resize_background(self, event):
        ''' Adatta l'immagine all'area della label.'''
        # se in inizializzazione adatto la finestra all'immagine.
        if self.load: self._verify_init()
        # adatto l'immagine alla nuova superficie della label
        w = event.width
        h = event.height
        self.img = self.img_copy.resize((w,h))
        # creo una nuova immagine di background
        self.bg_image = ImageTk.PhotoImage(self.img)
        # e la assegno alla label
        self.bg_label.configure(image=self.bg_image)


def center_window(gui):
    ''' Centra una finestra, passata quale parametro, sullo schermo.'''
    l = gui.winfo_screenwidth()
    a = gui.winfo_screenheight()
    wx = gui.winfo_reqwidth()
    wy = gui.winfo_reqheight()
    gui.geometry('{}x{}+{}+{}'.format(wx, wy, (l-wx)//2, (a-wy)//2))
    

if __name__ == '__main__':
    win = MainWin('resource/hal.png')
    win.mainloop()
